Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Clean Rooms.

Actions, resources, and condition keys for AWS Clean Rooms - Service Authorization Reference

# Actions, resources, and condition keys for AWS Clean Rooms

AWS Clean Rooms (service prefix: `cleanrooms` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Clean Rooms
- Resource types defined by AWS Clean Rooms
- Condition keys for AWS Clean Rooms

## Actions defined by AWS Clean Rooms

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchGetCollaborationAnalysisTemplate | Grants permission to view details of analysisTemplates associated to the collaboration | Read | analysistemplate* |  | cleanrooms:GetCollaborationAnalysisTemplate
collaboration* |  |
BatchGetSchema | Grants permission to view details for schemas | Read | collaboration* |  | cleanrooms:GetSchema
configuredtableassociation* |  |
CreateAnalysisTemplate | Grants permission to create a new analysis template | Write | analysistemplate* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
membership* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
CreateCollaboration | Grants permission to create a new collaboration, a shared data collaboration environment | Write | collaboration* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
CreateConfiguredAudienceModelAssociation | Grants permission to link a Cleanrooms ML configured audience model with a collaboration by creating a new association | Write | configuredaudiencemodelassociation* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys | cleanrooms-ml:GetConfiguredAudienceModel cleanrooms-ml:GetConfiguredAudienceModelPolicy cleanrooms-ml:PutConfiguredAudienceModelPolicy
membership* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
CreateConfiguredTable | Grants permission to create a new configured table | Write | configuredtable* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys | glue:BatchGetPartition glue:GetDatabase glue:GetDatabases glue:GetPartition glue:GetPartitions glue:GetSchemaVersion glue:GetTable glue:GetTables
CreateConfiguredTableAnalysisRule | Grants permission to create a analysis rule for a configured table | Write | configuredtable* |  |
CreateConfiguredTableAssociation | Grants permission to link a configured table with a collaboration by creating a new association | Write | configuredtable* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys | iam:PassRole
configuredtableassociation* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
membership* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
CreateMembership | Grants permission to join collaborations by creating a membership | Write | collaboration* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys | iam:PassRole logs:CreateLogDelivery logs:CreateLogGroup logs:DeleteLogDelivery logs:DescribeLogGroups logs:DescribeResourcePolicies logs:GetLogDelivery logs:ListLogDeliveries logs:PutResourcePolicy logs:UpdateLogDelivery s3:GetBucketLocation
membership* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
CreatePrivacyBudgetTemplate | Grants permission to create a new privacy budget template | Write | membership* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
privacybudgettemplate* | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
DeleteAnalysisTemplate | Grants permission to delete an existing analysis template | Write | analysistemplate* |  |
DeleteCollaboration | Grants permission to delete an existing collaboration | Write | collaboration* |  | cleanrooms-ml:DeleteConfiguredAudienceModelPolicy cleanrooms-ml:GetConfiguredAudienceModelPolicy cleanrooms-ml:PutConfiguredAudienceModelPolicy
DeleteConfiguredAudienceModelAssociation | Grants permission to delete an existing configured audience model association | Write | configuredaudiencemodelassociation* |  | cleanrooms-ml:DeleteConfiguredAudienceModelPolicy cleanrooms-ml:GetConfiguredAudienceModelPolicy cleanrooms-ml:PutConfiguredAudienceModelPolicy
DeleteConfiguredTable | Grants permission to delete a configured table | Write | configuredtable* |  |
DeleteConfiguredTableAnalysisRule | Grants permission to delete an existing analysis rule | Write | configuredtable* |  |
DeleteConfiguredTableAssociation | Grants permission to remove a configured table association from a collaboration | Write | configuredtableassociation* |  |
DeleteMember | Grants permission to delete members from a collaboration | Write | collaboration* |  | cleanrooms-ml:DeleteConfiguredAudienceModelPolicy cleanrooms-ml:GetConfiguredAudienceModelPolicy cleanrooms-ml:PutConfiguredAudienceModelPolicy
DeleteMembership | Grants permission to leave collaborations by deleting a membership | Write | membership* |  |
DeletePrivacyBudgetTemplate | Grants permission to delete an existing privacy budget template | Write | privacybudgettemplate* |  |
GetAnalysisTemplate | Grants permission to view details for an analysis template | Read | analysistemplate* |  |
GetCollaboration | Grants permission to view details for a collaboration | Read | collaboration* |  |
GetCollaborationAnalysisTemplate | Grants permission to view details for an analysis template within a collaboration | Read | analysistemplate* |  |
collaboration* |  |
GetCollaborationConfiguredAudienceModelAssociation | Grants permission to view details for a configured audience model association within a collaboration | Read | collaboration* |  |
configuredaudiencemodelassociation* |  |
GetCollaborationPrivacyBudgetTemplate | Grants permission to view details for a privacy budget template within a collaboration | Read | collaboration* |  |
privacybudgettemplate* |  |
GetConfiguredAudienceModelAssociation | Grants permission to view details for a configured audience model association | Read | configuredaudiencemodelassociation* |  |
GetConfiguredTable | Grants permission to view details for a configured table | Read | configuredtable* |  |
GetConfiguredTableAnalysisRule | Grants permission to view analysis rules for a configured table | Read | configuredtable* |  |
GetConfiguredTableAssociation | Grants permission to view details for a configured table association | Read | configuredtableassociation* |  |
GetMembership | Grants permission to view details about a membership | Read | membership* |  |
GetPrivacyBudgetTemplate | Grants permission to view details for a privacy budget template | Read | privacybudgettemplate* |  |
GetProtectedQuery | Grants permission to view a protected query | Read | membership* |  |
GetSchema | Grants permission to view details for a schema | Read | collaboration* |  |
configuredtableassociation* |  |
GetSchemaAnalysisRule | Grants permission to view analysis rules associated with a schema | Read | collaboration* |  | cleanrooms:GetSchema
configuredtableassociation* |  |
ListAnalysisTemplates | Grants permission to list available analysis templates | List | analysistemplate* |  |
membership* |  |
ListCollaborationAnalysisTemplates | Grants permission to list available analysis templates within a collaboration | List | collaboration* |  |
ListCollaborationConfiguredAudienceModelAssociations | Grants permission to list available configured audience model association within a collaboration | List | collaboration* |  |
ListCollaborationPrivacyBudgetTemplates | Grants permission to list available privacy budget templates within a collaboration | List | collaboration* |  |
ListCollaborationPrivacyBudgets | Grants permission to list privacy budgets within a collaboration | List | collaboration* |  |
ListCollaborations | Grants permission to list available collaborations | List |  |  |
ListConfiguredAudienceModelAssociations | Grants permission to list available configured audience model associations for a membership | List | configuredaudiencemodelassociation* |  |
membership* |  |
ListConfiguredTableAssociations | Grants permission to list available configured table associations for a membership | List | configuredtableassociation* |  |
membership* |  |
ListConfiguredTables | Grants permission to list available configured tables | List |  |  |
ListMembers | Grants permission to list the members of a collaboration | List | collaboration* |  |
ListMemberships | Grants permission to list available memberships | List |  |  |
ListPrivacyBudgetTemplates | Grants permission to list available privacy budget templates | List | membership* |  |
privacybudgettemplate* |  |
ListPrivacyBudgets | Grants permission to list available privacy budgets | List | membership* |  |
ListProtectedQueries | Grants permission to list protected queries | List | membership* |  |
ListSchemas | Grants permission to view available schemas for a collaboration | List | collaboration* |  |
ListTagsForResource | Grants permission to list tags for a resource | List | analysistemplate |  |
collaboration |  |
configuredaudiencemodelassociation |  |
configuredtable |  |
configuredtableassociation |  |
membership |  |
privacybudgettemplate |  |
PreviewPrivacyImpact | Grants permission to preview privacy budget template settings | Read | membership* |  |
StartProtectedQuery | Grants permission to start protected queries | Write | configuredtableassociation* |  | cleanrooms:GetCollaborationAnalysisTemplate cleanrooms:GetSchema s3:GetBucketLocation s3:ListBucket s3:PutObject
membership* |  |
analysistemplate |  |
TagResource | Grants permission to tag a resource | Tagging | analysistemplate |  |
collaboration |  |
configuredaudiencemodelassociation |  |
configuredtable |  |
configuredtableassociation |  |
membership |  |
privacybudgettemplate |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to untag a resource | Tagging | analysistemplate |  |
collaboration |  |
configuredaudiencemodelassociation |  |
configuredtable |  |
configuredtableassociation |  |
membership |  |
privacybudgettemplate |  |
| aws:TagKeys |
UpdateAnalysisTemplate | Grants permission to update details of the analysis template | Write | analysistemplate* |  |
UpdateCollaboration | Grants permission to update details of the collaboration | Write | collaboration* |  |
UpdateConfiguredAudienceModelAssociation | Grants permission to update a configured audience model association | Write | configuredaudiencemodelassociation* |  |
UpdateConfiguredTable | Grants permission to update an existing configured table | Write | configuredtable* |  |
UpdateConfiguredTableAnalysisRule | Grants permission to update analysis rules for a configured table | Write | configuredtable* |  |
UpdateConfiguredTableAssociation | Grants permission to update a configured table association | Write | configuredtableassociation* |  | iam:PassRole
UpdateMembership | Grants permission to update details of a membership | Write | membership* |  | iam:PassRole logs:CreateLogDelivery logs:CreateLogGroup logs:DeleteLogDelivery logs:DescribeLogGroups logs:DescribeResourcePolicies logs:GetLogDelivery logs:ListLogDeliveries logs:PutResourcePolicy logs:UpdateLogDelivery s3:GetBucketLocation
UpdatePrivacyBudgetTemplate | Grants permission to update details of the privacy budget template | Write | privacybudgettemplate* |  |
UpdateProtectedQuery | Grants permission to update protected queries | Write | membership* |  |

## Resource types defined by AWS Clean Rooms

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
analysistemplate | `arn:$ { Partition}:cleanrooms:$ { Region}:$ { Account}:membership/$ { MembershipId}/analysistemplate/$ { AnalysisTemplateId}` | aws:ResourceTag/${TagKey}
collaboration | `arn:$ { Partition}:cleanrooms:$ { Region}:$ { Account}:collaboration/$ { CollaborationId}` | aws:ResourceTag/${TagKey}
configuredaudiencemodelassociation | `arn:$ { Partition}:cleanrooms:$ { Region}:$ { Account}:membership/$ { MembershipId}/configuredaudiencemodelassociation/$ { ConfiguredAudienceModelAssociationId}` | aws:ResourceTag/${TagKey}
configuredtable | `arn:$ { Partition}:cleanrooms:$ { Region}:$ { Account}:configuredtable/$ { ConfiguredTableId}` | aws:ResourceTag/${TagKey}
configuredtableassociation | `arn:$ { Partition}:cleanrooms:$ { Region}:$ { Account}:membership/$ { MembershipId}/configuredtableassociation/$ { ConfiguredTableAssociationId}` | aws:ResourceTag/${TagKey}
membership | `arn:$ { Partition}:cleanrooms:$ { Region}:$ { Account}:membership/$ { MembershipId}` | aws:ResourceTag/${TagKey}
privacybudgettemplate | `arn:$ { Partition}:cleanrooms:$ { Region}:$ { Account}:membership/$ { MembershipId}/privacybudgettemplate/$ { PrivacyBudgetTemplateId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Clean Rooms

AWS Clean Rooms defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.